"""Test case for Mapping is unique"""

import unittest
import json
import os
import requests
from .base import Base

HOST = os.getenv("HOST", default="localhost")
PORT = os.getenv("PORT", default="8080")
API_KEY = os.getenv("API_KEY", "only4testingpurpose")


class TestMappingUnique(Base):
    """Test case for Mapping is unique class"""

    def test_that_mapping_is_unique(self) -> None:
        """Test that mapping is unique"""

        response = requests.post(
            url=f"http://{HOST}:{PORT}/api/plugins/rps/mapping/",
            json={
                "source": "https://truc8.com/api",
                "target": "http://10.10.10.10:1888/api",
                "authentication": "none",
                "testingpage": None,
            },
            headers={"Authorization": f"Token {API_KEY}"},
            timeout=5,
        )

        self.assertEqual(response.status_code, 201)

        self.mapping_id = json.loads(response.content)["id"]

        response = requests.post(
            url=f"http://{HOST}:{PORT}/api/plugins/rps/mapping/",
            json={
                "source": "https://truc8.com/api",
                "target": "http://10.10.10.10:1888/api",
                "authentication": "none",
                "testingpage": None,
            },
            headers={"Authorization": f"Token {API_KEY}"},
            timeout=5,
        )

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            response.content, b'{"source":["mapping with this Source already exists."]}'
        )

    def test_that_source_url_cannot_be_equal_to_destination_url(self) -> None:
        """Test that source ULR cannot be equal to destination URL"""

        response = requests.post(
            url=f"http://{HOST}:{PORT}/api/plugins/rps/mapping/",
            json={
                "source": "https://truc8.com/api",
                "target": "https://truc8.com/api",
                "authentication": "none",
                "testingpage": None,
            },
            headers={"Authorization": f"Token {API_KEY}"},
            timeout=5,
        )

        self.assertEqual(response.status_code, 400)
        self.assertEqual(
            response.content,
            b'{"target":["Target URL cannot be equal to source URL."]}',
        )


if __name__ == "__main__":
    unittest.main()
